'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var React = require('react');

var select = require('@highlight-ui/select');

var utilsCommons = require('@highlight-ui/utils-commons');

var utilsHooks = require('@highlight-ui/utils-hooks');

var classnames = require('classnames');

var tag = require('@highlight-ui/tag');

var typography = require('@highlight-ui/typography');

function _interopDefaultLegacy(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    'default': e
  };
}

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */


var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var styles = {
  "heading-xsmall": "TagInput-module__rZt-MAoi__v4-0-42",
  "heading-small": "TagInput-module__PQO8qq-u__v4-0-42",
  "heading-medium": "TagInput-module__sb2P2dCj__v4-0-42",
  "heading-large": "TagInput-module__u6r9LNvq__v4-0-42",
  "heading-xlarge": "TagInput-module__yhMOPIwv__v4-0-42",
  "heading-2xl": "TagInput-module__99de02nB__v4-0-42",
  "body-small": "TagInput-module__-YWEyzhu__v4-0-42",
  "body-base": "TagInput-module__uvD-T1i8__v4-0-42",
  "inputElement": "TagInput-module__bAs6W9xh__v4-0-42",
  "body-large": "TagInput-module__dd5qxlgf__v4-0-42",
  "body-strong-small": "TagInput-module__IwJqemwC__v4-0-42",
  "body-strong-base": "TagInput-module__Rv-hpgcq__v4-0-42",
  "body-strong-large": "TagInput-module__BGcf9hzb__v4-0-42",
  "page-heading": "TagInput-module__gU9E-wff__v4-0-42",
  "button": "TagInput-module__e1t9iSi9__v4-0-42",
  "form-label": "TagInput-module__i695kHR8__v4-0-42",
  "caption": "TagInput-module__IR9n-6LS__v4-0-42",
  "text-link-default": "TagInput-module__P5Q6WuUo__v4-0-42",
  "text-link-hover": "TagInput-module__5u2c3f8-__v4-0-42",
  "table-data-regular": "TagInput-module__aeQrzpZr__v4-0-42",
  "table-data-bold": "TagInput-module__FXcz-hxe__v4-0-42",
  "container": "TagInput-module__5Hsp6TSm__v4-0-42",
  "inputOutline": "TagInput-module__0mReyxP2__v4-0-42",
  "focused": "TagInput-module__5C3J1yy4__v4-0-42",
  "tag": "TagInput-module__IDTmOzFm__v4-0-42",
  "isHidden": "TagInput-module__ZXGxZax7__v4-0-42",
  "additionalTags": "TagInput-module__xm-NDWsK__v4-0-42",
  "suffix": "TagInput-module__mH8XDeHV__v4-0-42"
};

var getTagsShownNumber = function (tagElements, containerElement, suffixRef) {
  if (!tagElements.length) return 0;
  if (!containerElement.current) return 0;
  var prefixWidth = suffixRef.current ? suffixRef.current.offsetWidth + 24 : 0;
  var maxWidth = containerElement.current.offsetWidth - 40 - prefixWidth;
  var value = tagElements.slice(1).reduce(function (acc, item) {
    if (!item.current) return acc;

    if (maxWidth > acc.totalWidth + item.current.offsetWidth + 4) {
      return {
        items: acc.items + 1,
        totalWidth: acc.totalWidth + item.current.offsetWidth + 4
      };
    }

    return {
      items: acc.items,
      totalWidth: acc.totalWidth + item.current.offsetWidth
    };
  }, {
    items: 1,
    totalWidth: tagElements[0].current ? tagElements[0].current.offsetWidth + 4 : 0
  });
  return value.items;
};

var TagInput = React__default["default"].forwardRef(function (_a, ref) {
  var _b;

  var tags = _a.tags,
      onInputClick = _a.onInputClick,
      onInputChange = _a.onInputChange,
      onTagAdd = _a.onTagAdd,
      onTagRemove = _a.onTagRemove,
      suffix = _a.suffix,
      className = _a.className,
      metadata = _a.metadata,
      selectRef = _a.selectRef;

  var _c = React.useState(''),
      inputValue = _c[0],
      setInputValue = _c[1];

  var _d = React.useState(false),
      isFocused = _d[0],
      setFocus = _d[1];

  var _e = React.useState([]),
      elRefs = _e[0],
      setElRefs = _e[1];

  var inputRef = React.useRef(null);
  var innerRef = React.useRef(null);
  var suffixRef = React.useRef(null);

  var clearInput = function () {
    setInputValue('');

    if (onInputChange) {
      onInputChange('');
    }
  }; // TODO: refactor and remove selectRef from TagInput [PPUI-2030]


  var clickOutsideRef = utilsHooks.useClickOutside(function (event) {
    var _a;

    setFocus(false);

    if (inputValue) {
      if (!selectRef || selectRef && !((_a = selectRef.current) === null || _a === void 0 ? void 0 : _a.contains(event.target))) {
        onTagAdd(inputValue);
      }

      clearInput();
    }
  });
  var containerRef = utilsHooks.useForkRef([ref, clickOutsideRef, innerRef]);

  var _f = React.useState(0),
      tagsShownNumber = _f[0],
      setTagsShownNumber = _f[1];

  React.useEffect(function () {
    setElRefs(function (prevState) {
      return Array(tags.length).fill(0).map(function (_, i) {
        return prevState[i] || React.createRef();
      });
    });
  }, [tags]);
  React.useEffect(function () {
    if (elRefs && innerRef) {
      setTagsShownNumber(getTagsShownNumber(elRefs, innerRef, suffixRef));
    }
  }, [elRefs, innerRef]);
  return React__default["default"].createElement("div", __assign({
    className: classnames__default["default"](styles.container, className)
  }, utilsCommons.parseMetadata(metadata)), React__default["default"].createElement("div", {
    role: "none",
    onClick: function (e) {
      var _a;

      e.stopPropagation();
      e.preventDefault();
      (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    },
    ref: containerRef,
    className: classnames__default["default"](styles.inputOutline, (_b = {}, _b[styles.focused] = isFocused, _b))
  }, tags.map(function (tag$1, index) {
    var _a;

    return (// eslint-disable-next-line react/no-array-index-key
      React__default["default"].createElement(React__default["default"].Fragment, {
        key: index
      }, React__default["default"].createElement(tag.Tag, __assign({}, tag$1, {
        metadata: utilsCommons.suffixMetadata(metadata, "tag-" + index),
        ref: elRefs[index],
        className: classnames__default["default"](styles.tag, (_a = {}, _a[styles.isHidden] = !isFocused && index >= tagsShownNumber, _a)),
        onRemove: function (e) {
          e.stopPropagation();
          onTagRemove(tag$1, index);
        }
      })), !isFocused && index === tagsShownNumber - 1 && tags.length > tagsShownNumber && React__default["default"].createElement(tag.Tag, {
        className: styles.additionalTags,
        text: "+" + (tags.length - tagsShownNumber)
      }))
    );
  }), React__default["default"].createElement("input", {
    ref: inputRef,
    className: styles.inputElement,
    value: inputValue,
    onKeyDown: function (event) {
      var value = event.currentTarget.value;

      if (value) {
        if (event.key === 'Enter' || event.key === 'Tab' || event.key === ',') {
          onTagAdd(value);
          clearInput();
        }
      }
    },
    onChange: function (event) {
      var input = event.target.value;

      if (input !== ',') {
        setInputValue(input);

        if (onInputChange) {
          onInputChange(input);
        }
      }
    },
    onFocus: function () {
      if (!isFocused) {
        setFocus(true);

        if (onInputClick) {
          onInputClick();
        }
      }
    }
  }), suffix && React__default["default"].createElement(typography.Typography, {
    ref: suffixRef,
    token: "body-strong-small",
    className: styles.suffix
  }, suffix)));
});

function TagPickerWithRef(_a, ref) {
  var tags = _a.tags,
      onInputChange = _a.onInputChange,
      onTagAdd = _a.onTagAdd,
      onTagRemove = _a.onTagRemove,
      options = _a.options,
      className = _a.className,
      metadata = _a.metadata,
      suffix = _a.suffix;

  var _b = React.useState(''),
      highlightedText = _b[0],
      setHighlightedText = _b[1];

  var handleOnInputChange = React.useCallback(function (input) {
    setHighlightedText(input);

    if (onInputChange) {
      onInputChange(input);
    }
  }, [onInputChange]);
  var renderTriggerCallback = React.useCallback(function (_a) {
    var onClick = _a.onClick,
        triggerRef = _a.ref,
        selectRef = _a.selectRef;
    return React__default["default"].createElement(TagInput, {
      metadata: utilsCommons.suffixMetadata(metadata, 'tag-input'),
      tags: tags,
      onInputClick: onClick,
      onInputChange: handleOnInputChange,
      onTagAdd: onTagAdd,
      onTagRemove: onTagRemove,
      suffix: suffix,
      ref: triggerRef,
      selectRef: selectRef
    });
  }, [handleOnInputChange, metadata, onTagAdd, onTagRemove, suffix, tags]);
  return React__default["default"].createElement(select.Select, {
    ref: ref,
    className: className,
    metadata: metadata,
    renderTrigger: renderTriggerCallback,
    closeOnSelect: true,
    highlightedText: highlightedText,
    searchable: false,
    options: options,
    renderEmptyState: function () {
      return null;
    },
    onSelect: function (option) {
      return onTagAdd(option[0].label);
    }
  });
}

TagPickerWithRef.displayName = 'TagPicker';
var TagPicker = React__default["default"].forwardRef(TagPickerWithRef);
exports.TagInput = TagInput;
exports.TagPicker = TagPicker;
//# sourceMappingURL=index.js.map
